============================
django-transaction-hooks
============================

.. image:: https://secure.travis-ci.org/carljm/django-transaction-hooks.png?branch=master
   :target: http://travis-ci.org/carljm/django-transaction-hooks
.. image:: https://coveralls.io/repos/carljm/django-transaction-hooks/badge.png?branch=master
   :target: https://coveralls.io/r/carljm/django-transaction-hooks
.. image:: https://pypip.in/v/django-transaction-hooks/badge.png
   :target: https://pypi.python.org/pypi/django-transaction-hooks

Django database backends with post-transaction-commit callback hooks.

``django-transaction-hooks`` supports `Django`_ 1.6.1 and later on Python 2.6,
2.7, 3.2, and 3.3.

.. _Django: http://www.djangoproject.com/


Getting Help
============

Documentation for django-transaction-hooks is available at
https://django-transaction-hooks.readthedocs.org/

This app is available on `PyPI`_ and can be installed with ``pip install
django-transaction-hooks``.

.. _PyPI: https://pypi.python.org/pypi/django-transaction-hooks/


Contributing
============

See the `contributing docs`_.

.. _contributing docs: https://github.com/carljm/django-transaction-hooks/blob/master/CONTRIBUTING.rst

